@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0901';
+our $VERSION = '0.1000';
 
 use Moo;
 use Music::Chord::Note;
@@ -112,6 +112,8 @@ sub cadence {
     }
     elsif ( $args{type} eq 'half' ) {
         my $chord = $self->_generate_chord( $args{scale}, $scale[ $args{leading} - 1 ], $args{octave}, $mtr, $mcn );
+        $chord = $self->_invert_chord( $chord, $args{inversion}->{1}, $args{octave} )
+            if $args{inversion} && $args{inversion}->{1};
         push @$cadence, $chord;
 
         $chord = $self->_generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
@@ -141,7 +143,7 @@ sub _invert_chord {
         $chord = $mcp->chord_inv( $chord, inv_num => $inversion );
     }
     else {
-        # Perform these gymnastics to convert from named notes to inverted named notes
+        # Perform gymnastics to convert from named notes to inverted named notes
         my $notes = $chord;
 
         $notes = [ grep { s/\d+// } @$notes ]
@@ -221,7 +223,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0901
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -241,7 +243,8 @@ version 0.0901
     type    => 'half',
     leading => 2,
     octave  => 0,
-  ); # [['D','F','A'], ['G','B','D']]
+  );
+  # [['D','F','A'], ['G','B','D']]
 
   $mc = Music::Cadence->new(
     key    => 'C#',
@@ -410,6 +413,9 @@ this is:
   Am: 6
   Bo: 7
 
+If an B<inversion> is defined for the C<half> cadence, the first chord
+is inverted.
+
 =head1 SEE ALSO
 
 The F<eg/cadence> and F<t/01-methods.t> files in this distribution.
@@ -430,10 +436,6 @@ L<https://en.wikipedia.org/wiki/Cadence>
 
 L<https://www.musictheoryacademy.com/how-to-read-sheet-music/cadences/>
 
-=head1 TO DO
-
-Evaded cadence
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
